The SolrResult object represents the result of a Solr query and
usually contains a collection of documents and/or facets. The default
implementation, ListSolrResult, directly stores the canonical
JSON response from Solr. It is usually obtained by
evaluating a
SolrQuery on a SolrCore, which most users will never do.
Since ListSolrResult inherits from list, one can access
the raw JSON fields directly through the ordinary list accessors. One
should only directly manipulate the Solr response when extending
rsolr/Solr at a deep level. Higher-level accessors are described below.
docs and
facets on SolrCore are
more convenient and usually sufficient